@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -45,10 +45,7 @@ duc_dummy (void *cls, int delta)
 static int
 test_config (const char *name)
 {
-  struct GNUNET_DATASTORE_PluginEnvironment env = {
-    cfg,
-    &duc_dummy, NULL
-  };
+  struct GNUNET_DATASTORE_PluginEnvironment env = {cfg, &duc_dummy, NULL};
   void *ret;
 
   ret = GNUNET_PLUGIN_load (name, &env);
@@ -90,7 +87,7 @@ GNUNET_setup_datastore_postgres_invalidate_cb ()
 
 
 void
-GNUNET_setup_datastore_mysql_tab_test_button_clicked_cb (GtkWidget * widget,
+GNUNET_setup_datastore_mysql_tab_test_button_clicked_cb (GtkWidget *widget,
                                                          gpointer user_data)
 {
   if (GNUNET_OK == test_config ("libgnunet_plugin_datastore_mysql"))
@@ -107,7 +104,7 @@ GNUNET_setup_datastore_mysql_tab_test_button_clicked_cb (GtkWidget * widget,
 
 
 void
-GNUNET_setup_datastore_postgres_tab_test_button_clicked_cb (GtkWidget * widget,
+GNUNET_setup_datastore_postgres_tab_test_button_clicked_cb (GtkWidget *widget,
                                                             gpointer user_data)
 {
   if (GNUNET_OK == test_config ("libgnunet_plugin_datastore_postgres"))
@@ -123,5 +120,4 @@ GNUNET_setup_datastore_postgres_tab_test_button_clicked_cb (GtkWidget * widget,
 }
 
 
-
 /* end of gnunet-setup-datastore-config.c */
